/*****************************************************************************
 * Copyright (C) 2000 Jim Kent.  This source code may be freely used         *
 * for personal, academic, and non-profit purposes.  Commercial use          *
 * permitted only by explicit agreement with Jim Kent (jim_kent@pacbell.net) *
 *****************************************************************************/
#include "common.h"
#include "dnautil.h"
#include "memgfx.h"
#include "fuzzyFind.h"
#include "htmshell.h"
#include "cda.h"


struct cfm
/* Output formatter. */
    {
    int wordLen, lineLen;
    int inWord, inLine;
    boolean lineNumbers;
    int lastColor;
    long charCount;
    FILE *out;
    int numOff;
    };

static void initCfm(struct cfm *cfm, int wordLen, int lineLen, 
	boolean lineNumbers, FILE *out, int numOff)
/* Set up formatting. */
{
cfm->inWord = cfm->inLine = cfm->charCount = 0;
cfm->lastColor = 0;
cfm->wordLen = wordLen;
cfm->lineLen = lineLen;
cfm->lineNumbers = lineNumbers;
cfm->out = out;
cfm->numOff = numOff;
fprintf(cfm->out, "<FONT COLOR=\"#00%X\">", 0);
}

static void cfmOut(struct cfm *cfm, char c, int color)
/* Write out a byte, and depending on formatting extras
 */
{
if (color != cfm->lastColor)
    {
    fprintf(cfm->out, "</FONT><FONT COLOR=\"#00%X\">", color);
    cfm->lastColor = color;
    }
++cfm->charCount;
fputc(c, cfm->out);
if (cfm->wordLen)
    {
    if (++cfm->inWord >= cfm->wordLen)
	{
	fputc(' ', cfm->out);
	cfm->inWord = 0;
	}
    }
if (cfm->lineLen)
    {
    if (++cfm->inLine >= cfm->lineLen)
	{
	if (cfm->lineNumbers)
	    fprintf(cfm->out, " %ld", cfm->charCount+cfm->numOff);
	fprintf(cfm->out, "<BR>\n");
	cfm->inLine = 0;
	}
    }
}

static void cfmCleanup(struct cfm *cfm)
{
fprintf(cfm->out, "</FONT>\n");
}

struct baf
/* Block allignment formatter. */
    {
    char nChars[50];
    char hChars[50];
    int cix;
    int nLineStart;
    int hLineStart;
    int nCurPos;
    int hCurPos;
    DNA *needle, *haystack;
    int nNumOff, hNumOff;
    FILE *out;
    };

static void bafInit(struct baf *baf, DNA *needle, int nNumOff, DNA *haystack, int hNumOff, FILE *out)
{
baf->cix = 0;
baf->needle = needle;
baf->haystack = haystack;
baf->nNumOff = nNumOff;
baf->hNumOff = hNumOff;
baf->out = out;
}

static void bafSetAli(struct baf *baf, struct ffAli *ali)
{
baf->nCurPos = ali->nStart - baf->needle;
baf->hCurPos = ali->hStart - baf->haystack;
}

static void bafStartLine(struct baf *baf)
{
baf->nLineStart = baf->nCurPos;
baf->hLineStart = baf->hCurPos;
}

static int digitsBaseTen(int x)
{
int digCount = 1;
while (x >= 10)
    {
    digCount += 1;
    x /= 10;
    }
return digCount;
}

static int maxDigits(int x, int y)
{
int xDigits = digitsBaseTen(x);
int yDigits = digitsBaseTen(y);
return (xDigits > yDigits ? xDigits : yDigits);
}

static void bafWrite(struct baf *baf)
{
int i;
int count = baf->cix;
int startDigits = maxDigits(baf->nLineStart+1+baf->nNumOff, baf->hLineStart+1+baf->hNumOff);
int endDigits = maxDigits(baf->nCurPos+baf->nNumOff, baf->hCurPos+baf->hNumOff);

fprintf(baf->out, "%0*d ", startDigits, baf->nLineStart+1+baf->nNumOff);
for (i=0; i<count; ++i)
    fputc(baf->nChars[i], baf->out);
fprintf(baf->out, " %0*d<BR>\n", endDigits, baf->nCurPos+baf->nNumOff);

for (i=0; i<startDigits; ++i)
    fputc('>', baf->out);
fputc(' ', baf->out);
for (i=0; i<count; ++i)
    fputc( (toupper(baf->nChars[i]) == toupper(baf->hChars[i]) ? '|' : '.'), baf->out);
fputc(' ', baf->out);
for (i=0; i<endDigits; ++i)
    fputc('<', baf->out);
fprintf(baf->out, "<BR>\n");

fprintf(baf->out, "%0*d ", startDigits, baf->hLineStart+1+baf->hNumOff);
for (i=0; i<count; ++i)
    fputc(baf->hChars[i], baf->out);
fprintf(baf->out, " %0*d<BR>\n<BR>\n", endDigits, baf->hCurPos+baf->hNumOff);
}

static void bafOut(struct baf *baf, char n, char h)
{
baf->nChars[baf->cix] = n;
baf->hChars[baf->cix] = h;
baf->nCurPos += 1;
baf->hCurPos += 1;
if (++(baf->cix) >= sizeof(baf->nChars))
    {
    bafWrite(baf);
    baf->cix = 0;
    baf->nLineStart = baf->nCurPos;
    baf->hLineStart = baf->hCurPos;
    }
}

void horLine(FILE *f)
/* Write horizontal line to html file. */
{
fputs("<P><HR ALIGN=CENTER></P>",f);
}

static void bafFlushLine(struct baf *baf)
{
bafWrite(baf);
horLine(baf->out);
baf->cix = 0;
}

enum cfv
    {
    cfvBlack = 0,
    cfvBlue = 1,
    cfvBrightBlue = 2,
    };

int cfvLookup[3] = 
    {
    0x000000,
    0x0033FF,
    0xaa00FF,
    };

void ffShAli(FILE *f, struct ffAli *aliList, 
    char *needleName, DNA *needle, int needleSize, int needleNumOffset,
    char *haystackName, DNA *haystack, int haySize, int hayNumOffset,
    boolean rcNeedle)
/* Display allignment on html page. */
{
struct cfm cfm;
long i;
struct ffAli *ali;
struct ffAli *lastAli;
struct ffAli *leftAli = aliList;
int startMatchIx;
int charsInLine;
struct baf baf;
int maxSize = (needleSize > haySize ? needleSize : haySize);
char *colorFlags = needMem(maxSize);
static int anchorCount = 0;

fputs("<CENTER><P><TABLE BORDER=1 WIDTH=\"97%\"><TR>", f);
fputs("<TD WIDTH=\"23%\"><P ALIGN=CENTER><A HREF=\"#cDNA\">cDNA Sequence</A></TD>", f);
fputs("<TD WIDTH=\"27%\"><P ALIGN=\"CENTER\"><A HREF=\"#genomic\">Genomic Sequence</A></TD>", f);
fputs("<TD WIDTH=\"29%\"><P ALIGN=\"CENTER\"><A HREF=\"#1\">cDNA in Genomic</A></TD>", f);
fputs("<TD WIDTH=\"21%\"><P ALIGN=\"CENTER\"><A HREF=\"#ali\">Side by Side</A></TD>", f);
fputs("</TR></TABLE>", f);
fputs("Matching bases in cDNA and genomic sequences are colored blue. ", f);
fputs("Light blue bases indicate gaps in the alignment.<BR>", f);
fputs("Predicted exons are in upper case.", f);
fputs("</P></CENTER>", f);
horLine(f);

fprintf(f, "<TT>\n");
fprintf(f, "<H4><A NAME=cDNA></A>cDNA %s%s</H4>\n", needleName, (rcNeedle ? " (reverse complemented)" : ""));

if (aliList == NULL)
    leftAli = NULL;
else
    {
    while (leftAli->left != NULL) leftAli = leftAli->left;
    }
if (rcNeedle)
    reverseComplement(needle, needleSize);
initCfm(&cfm, 10, 50, TRUE, f, needleNumOffset);
zeroBytes(colorFlags, needleSize);
for (ali = leftAli; ali != NULL; ali = ali->right)
    {
    int i;
    int off = ali->nStart-needle;
    int count = ali->nEnd - ali->nStart;
    for (i=0; i<count; ++i)
        {
        if (toupper(ali->hStart[i]) == toupper(ali->nStart[i]))
            colorFlags[off+i] = ((i == 0 || i == count-1) ? cfvBrightBlue : cfvBlue);
        }
    }
for (i=0; i<needleSize; ++i)
    {
    cfmOut(&cfm, needle[i], cfvLookup[colorFlags[i]]);
    }
cfmCleanup(&cfm);

horLine(f);
fprintf(f, "<H4><A NAME=genomic></A>Genomic %s:</H4>\n", haystackName);
initCfm(&cfm, 10, 50, TRUE, f, hayNumOffset);
zeroBytes(colorFlags, haySize);
for (ali = leftAli; ali != NULL; ali = ali->right)
    {
    int i;
    int off = ali->hStart-haystack;
    int count = ali->hEnd - ali->hStart;
    for (i=0; i<count; ++i)
        {
        if (toupper(ali->hStart[i]) == toupper(ali->nStart[i]))
            colorFlags[off+i] = ((i == 0 || i == count-1) ? cfvBrightBlue : cfvBlue);
        }
    }
if (leftAli != NULL)
    startMatchIx = leftAli->hStart - haystack;
else
    startMatchIx = 0;
for (i=0; i<haySize; ++i)
    {
    /* Put down "anchor" on first match position in haystack
     * so user can hop here with a click on the needle. */
    if (i == startMatchIx)
        fprintf(f, "<A NAME=1></A>", anchorCount);
    cfmOut(&cfm, haystack[i], cfvLookup[colorFlags[i]]);
    }
cfmCleanup(&cfm);

horLine(f);
fprintf(f, "<H4><A NAME=ali></A>Side by Side Alignment</H4>\n");
lastAli = NULL;
charsInLine = 0;
bafInit(&baf, needle, 0, haystack, hayNumOffset, f);
for (ali=leftAli; ali!=NULL; ali = ali->right)
    {
    boolean doBreak = TRUE;
    int aliLen;
    int i;

    /* Decide whether to put in a line break and/or blank characters */
    if (lastAli != NULL)
        {
        int nSkip = ali->nStart - lastAli->nEnd;
        int hSkip = ali->hStart - lastAli->hEnd;
        if (nSkip >= 0 && hSkip >= 0 && nSkip <= 8 && hSkip <= 8)
            {
            if (nSkip > 0 && hSkip == 0)
                {
                for (i=0; i<nSkip; ++i)
                    bafOut(&baf, lastAli->nEnd[i],'.');
                doBreak = FALSE; 
                }
            if (hSkip > 0 && nSkip == 0)
                {
                for (i=0; i<hSkip; ++i)
                    bafOut(&baf, '.', lastAli->hEnd[i]);
                doBreak = FALSE;
                }
            if (hSkip == nSkip)
                {
                for (i=0; i<hSkip; ++i)
                    bafOut(&baf, lastAli->nEnd[i], lastAli->hEnd[i]);
                doBreak = FALSE;
                }
            }
        }
    else
        {
        doBreak = FALSE;
        }
    if (doBreak)
        bafFlushLine(&baf);
    bafSetAli(&baf, ali);
    if (doBreak || lastAli == NULL)
        bafStartLine(&baf);
    aliLen = ali->nEnd - ali->nStart;
    for (i=0; i<aliLen; ++i)
        {
        bafOut(&baf, ali->nStart[i], ali->hStart[i]);
        }
    lastAli = ali;
    }
if (leftAli != NULL)
    bafFlushLine(&baf);
fprintf(f, "</TT>\n");
if (rcNeedle)
    reverseComplement(needle, needleSize);
}


void ffShowAli(struct ffAli *aliList, char *needleName, DNA *needle, int needleNumOffset,
    char *haystackName, DNA *haystack, int hayNumOffset, boolean rcNeedle)
/* Display allignment on html page. */
{
ffShAli(stdout, aliList, needleName, needle, strlen(needle), needleNumOffset,
    haystackName, haystack, strlen(haystack), hayNumOffset, rcNeedle);
}


static struct cdaAli *makeBlocks(struct ffAli *aliList, 
    DNA *needle, int needleSize, DNA *hay, int haySize, boolean isRc)
/* Merge together blocks separated only by noise, and evaluate
 * left, right, and middle of block for alignment strength. */
{
struct cdaAli *ca = cdaAliFromFfAli(aliList, 
    needle, needleSize, hay, haySize, isRc);
cdaCoalesceBlocks(ca);
return ca;
}

#ifdef OLD
void ffShowAlignmentTrack(struct memGfx *mg, 
    int xOff, int yOff, int width, int height,
    DNA *needle, int needleSize, DNA *hay, int haySize,
    struct ffAli *aliList, boolean isRc)
/* Draw alignment on a horizontal track of picture. */
{
struct cdaAli *cda;
cda = makeBlocks(aliList, needle, needleSize, hay, haySize, isRc);
cdaShowAlignmentTrack(mg, xOff, yOff, width, height, MG_BLACK, MG_GRAY,
    haySize, 0, cda);
cdaFreeAli(cda);
}


void ffDoAlignmentTrack(struct memGfx *mg, 
    int xOff, int yOff, int width, int height,
    DNA *needle, int needleSize, DNA *hay, int haySize)
/* Do alignment and display it on a track. */
{
struct ffAli *aliList;
boolean isRc;
if (ffFindEitherStrandN(needle, needleSize, hay, haySize, ffCdna, &aliList, &isRc))
    {
    ffShowAlignmentTrack(mg, xOff, yOff, width, height,
        needle, needleSize, hay, haySize, aliList, isRc);
    ffFreeAli(&aliList);
    }
}
#endif /* OLD */    


